PROGRAM_NAME='GENTNER, AP800, RS-232, BASIC, 9-99, RDW'
(*   DATE:09/21/99    TIME:17:31:21    *)
(***********************************************************)
(* The following code block is provided as a guide to      *)
(* programming the device(s) listed above. This is a       *)
(* sample only, and will most likely require modification  *)
(* to be integrated into a master program.                 *)
(*                                                         *)
(* Device-specific protocols should be obtained directly   *)
(* from the equipment manufacturer to ensure compliance    *)
(* with the most current versions. Within the limits       *)
(* imposed by any non-disclosure agreements, AMX will      *)
(* provide protocols upon request.                         *)
(*                                                         *)
(* If further programming assistance is required, please   *)
(* contact your AMX customer support team.                 *)
(*                                                         *)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

AP800 = 2                              (* GENTNER AP800 9600,N,8,1 *)
TP    = 128                            (* AXT-CP *)

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

S_DATE        = '06/03/98'
S_TIME        = '11:30:00'

OUTPUT_STR    = 'D O' (* MASTER VOLUME - OUTPUT D *)
INPUT_STR     = '* I'  (* INPUTS 1 THRU 8 (FOR PRIVACY MUTE) *)

VOLUME_RAMP   = 5    (* WAIT TIME FOR RAMPING VOLUME *)

(*** GENTNER COMMAND TYPES ***)
DIAL          = 0
CONNECT       = 1
DISCONNECT    = 2

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

TEL_CONF           (* FLAG: IF TELEPHONE CONFERENCE ON *)
VID_CONF           (* FLAG: IF TELEPHONE CONFERENCE ON *)
VOL_LEVEL          (* MASTER VOLUME LEVEL (0-40) *)
RAMP_UP            (* FLAG: IF TELEPHONE VOLUME UP BUTTON PUSHED *)
RAMP_DN            (* FLAG: IF TELEPHONE VOLUME UP BUTTON PUSHED *)
CHAN_MUTE          (* FLAG: IF CHANNEL IS MUTED *)

LAST_LEN
DIAL_NUM[30]

AP_BUFFER[100]     (* BUFFER FOR RESPONSES FROM AP800 & AP10 *)
AP_RESPONSE[20]    (* NEXT COMPLETE RESPONSE IN THE BUFFER *)
BUFFER_POS         (* FOR LOCATING POSITIONS IN THE BUFFER *)
VID_CONF_IN        (* FLAG IF VIDEO CONFERENCE INPUT CHANNEL MUTED *)
VID_CONF_OUT       (* FLAG IF VIDEO CONFERENCE OUTPUT CHANNEL MUTED *)

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

(***********************************************************)
(*           SUBROUTINE DEFINITIONS GO BELOW               *)
(***********************************************************)

DEFINE_CALL 'SEND GAIN COMMAND'
LOCAL_VAR VAL_STR[3]
{
  IF (VOL_LEVEL >= 20)
    VAL_STR = ITOA(VOL_LEVEL-20)
  ELSE
    VAL_STR = "'-',ITOA(20-VOL_LEVEL)"

  SEND_STRING AP800,"'#10 GAIN ',OUTPUT_STR,' ',VAL_STR,' A',$0D"
  SEND_STRING AP800,"'#11 GAIN ',OUTPUT_STR,' ',VAL_STR,' A',$0D"
}

DEFINE_CALL 'INCREASE VOLUME'
{
  IF (VOL_LEVEL < 40)
  {
    VOL_LEVEL = VOL_LEVEL + 1
    CALL 'SEND GAIN COMMAND'
  }
  ELSE IF (RAMP_UP)
    OFF[RAMP_UP]
}

DEFINE_CALL 'DECREASE VOLUME'
{
  IF (VOL_LEVEL > 0)
  {
    VOL_LEVEL = VOL_LEVEL - 1
    CALL 'SEND GAIN COMMAND'
  }
  ELSE IF (RAMP_DN)
    OFF[RAMP_DN]
}

DEFINE_CALL 'MUTE VOLUME'
{
  IF (CHAN_MUTE)
  {
    SEND_STRING AP800,"'#10 MUTE ',INPUT_STR,' 0',$0D"
    SEND_STRING AP800,"'#11 MUTE ',INPUT_STR,' 0',$0D"
  }
  ELSE
  {
    SEND_STRING AP800,"'#10 MUTE ',INPUT_STR,' 1',$0D"
    SEND_STRING AP800,"'#11 MUTE ',INPUT_STR,' 1',$0D"
  }
}

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START

CREATE_BUFFER AP800,AP_BUFFER

SEND_COMMAND AP800, 'HSON'
SEND_COMMAND AP800, 'CHARD-100'

(* MODEM INITIALIZATION STRING *****************************)
WAIT 50                                 (* wait for other stuff *)
{
    SEND_STRING 0,"13,13"               (* CLEAR *)
    WAIT 10 SEND_STRING 0,"'ATE0',13"   (* Echo Off *)
    WAIT 20 SEND_STRING 0,"'AT&F',13"   (* Factory Default *)
    WAIT 30 SEND_STRING 0,"'ATE0',13"   (* Echo Off *)
    WAIT 40 SEND_STRING 0,"'ATS0=3',13" (* Auto Answer=3 rings *)
    WAIT 50 SEND_STRING 0,"'AT&D0',13"  (* Ignore DTR Handshaking *)
    WAIT 60 SEND_STRING 0,"'AT&Q0',13"  (* Disable error/compression *)
}
(* END *****************************************************)
(* Define Default Settings *********************************)

SET_TIMER(0)
DIAL_NUM=''

VOL_LEVEL = 20

(***********************************************************)
(*            THE ACTUAL PROGRAM GOES BELOW                *)
(***********************************************************)
DEFINE_PROGRAM

(*** TELEPHONE CONFERENCE ***)
PUSH[TP,1]                            (* CONNECT AP10 TO TELEPHONE LINE *)
  SEND_STRING AP800,"'#20 TE 1',$0D"

PUSH[TP,2]                            (* DISCONNECT AP10 FROM LINE *)
  SEND_STRING AP800,"'#20 TE 0',$0D"

[TP,1] = TEL_CONF
[TP,2] = NOT(TEL_CONF)


(*** VIDEO CONFERENCE ***)
PUSH[TP,6]                            (* UNMUTE INPUT AND OUTPUT A *)
{
  SEND_STRING AP800,"'#10 MUTE A I 0',$0D"
  SEND_STRING AP800,"'#10 MUTE A O 0',$0D"
}
PUSH[TP,7]                            (* MUTE INPUT AND OUTPUT A *)
{
  SEND_STRING AP800,"'#10 MUTE A I 1',$0D"
  SEND_STRING AP800,"'#10 MUTE A O 1',$0D"
}

[TP,6] = VID_CONF
[TP,7] = NOT(VID_CONF)


(*** VOLUME ***)
PUSH[TP,11]                            (* MASTER VOLUME UP *)
{
  OFF[RAMP_DN]
  ON[RAMP_UP]
  CALL 'INCREASE VOLUME'
}
PUSH[TP,12]                            (* MASTER VOLUME DOWN *)
{
  OFF[RAMP_UP]
  ON[RAMP_DN]
  CALL 'DECREASE VOLUME'
}
RELEASE[TP,11]
RELEASE[TP,12]
{
  CANCEL_WAIT 'RAMP'
  OFF[RAMP_UP]
  OFF[RAMP_DN]
}
[TP,11] = RAMP_UP
[TP,12] = RAMP_DN

SEND_LEVEL TP,1,((VOL_LEVEL*255)/40)

IF (RAMP_UP)
  WAIT VOLUME_RAMP 'RAMP'
    CALL 'INCREASE VOLUME'
ELSE IF (RAMP_DN)
  WAIT VOLUME_RAMP 'RAMP'
    CALL 'DECREASE VOLUME'


PUSH[TP,13]                           (* MASTER VOLUME MUTE *)
  CALL 'MUTE VOLUME'
[TP,13] = CHAN_MUTE

(*** DIALING ***)
LAST_LEN=LENGTH_STRING(DIAL_NUM)

IF (GET_TIMER > 600)
{
  SET_TIMER(0)
  DIAL_NUM=''
}

PUSH[TP,17]                           (* CLEAR DISPLAY *)
{
  DIAL_NUM=''
  SET_TIMER(0)
}

PUSH[TP,18]                           (* DIAL '*' *)
{
  SEND_STRING AP800,"'#20 DIAL *',$0D"
  DIAL_NUM="DIAL_NUM, '*'"
}
PUSH[TP,19]                           (* DIAL '#' *)
{
  SEND_STRING AP800,"'#20 DIAL #',$0D"
  DIAL_NUM="DIAL_NUM, '#'"
}

PUSH[TP,20]                           (* DIAL NUMBERS 0 - 9 *)
PUSH[TP,21]
PUSH[TP,22]
PUSH[TP,23]
PUSH[TP,24]
PUSH[TP,25]
PUSH[TP,26]
PUSH[TP,27]
PUSH[TP,28]
PUSH[TP,29]
{
  SEND_STRING AP800,"'#20 DIAL ', ITOA(PUSH_CHANNEL-20), $0D"
  DIAL_NUM="DIAL_NUM, ITOA(PUSH_CHANNEL-20)"
}

IF (LENGTH_STRING(DIAL_NUM) <> LAST_LEN)
{
  SEND_COMMAND TP,"'!F',1,'2'"
  SEND_COMMAND TP,"'TEXT1-',DIAL_NUM"
  SET_TIMER(0)
}

(*** BUFFER PROCESSING ***)
IF (LENGTH_STRING(AP_BUFFER))
{
  IF (FIND_STRING(AP_BUFFER,"$0D",1))
  {
    CANCEL_WAIT 'CLEAR BUFFER'
    AP_RESPONSE = REMOVE_STRING(AP_BUFFER,"$0D",1)

    IF (FIND_STRING(AP_RESPONSE,'#1',1)) (* AP800 RESPONSE *)
      SELECT
      {
        ACTIVE (FIND_STRING(AP_RESPONSE,' MUTE ',1)):
        {
          BUFFER_POS = FIND_STRING(AP_RESPONSE,' MUTE ',1) + 6
          IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = 'A')
          {                            (* VIDEO CONNECT STATUS *)
            BUFFER_POS = FIND_STRING(AP_RESPONSE,' MUTE ',1) + 8
            IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = 'I')
            {
              BUFFER_POS = FIND_STRING(AP_RESPONSE,' MUTE ',1) + 10
              IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = '0')
                OFF[VID_CONF_IN]
              ELSE IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = '1')
                ON[VID_CONF_IN]
            }
            ELSE IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = 'O')
            {
              BUFFER_POS = FIND_STRING(AP_RESPONSE,' MUTE ',1) + 10
              IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = '0')
                OFF[VID_CONF_OUT]
              ELSE IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = '1')
                ON[VID_CONF_OUT]
            }
            IF (VID_CONF_IN AND VID_CONF_OUT)
              ON[VID_CONF]
            ELSE
              OFF[VID_CONF]
          }
          ELSE IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = '*')
          {                            (* MICROPHONE MUTES *)
            BUFFER_POS = FIND_STRING(AP_RESPONSE,' MUTE ',1) + 10
            IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = '0')
              OFF[CHAN_MUTE]
            ELSE IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = '1')
              ON[CHAN_MUTE]
          }
        }
        ACTIVE (FIND_STRING(AP_RESPONSE,' GAIN ',1)):
        {                              (* VOLUME LEVEL *)
          BUFFER_POS = FIND_STRING(AP_RESPONSE,' GAIN ',1) + 10
          SEND_LEVEL TP,1,((VOL_LEVEL*255)/40)
        }
      }
    ELSE IF (FIND_STRING(AP_RESPONSE,'#2',1)) (* AP10 RESPONSE *)
      SELECT
      {
        ACTIVE (FIND_STRING(AP_RESPONSE,' TE ',1)):
        {                              (* TELEPHONE CONNECT STATUS *)
          BUFFER_POS = FIND_STRING(AP_RESPONSE,' TE ',1) + 4
          IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = '1')
            ON[TEL_CONF]
          ELSE IF (MID_STRING(AP_RESPONSE,BUFFER_POS,1) = '0')
            OFF[TEL_CONF]
        }
      }
  }
  ELSE
    WAIT 10 'CLEAR BUFFER'
      CLEAR_BUFFER AP_BUFFER
}

(***********************************************************)
(*                     END OF PROGRAM                      *)
(*        DO NOT PUT ANY CODE BELOW THIS COMMENT           *)
(***********************************************************)

